Of course! Here's an `architecture.md` file that outlines the system architecture for your Raspberry Pi ECM spoofing project:

---

# `architecture.md` – ECM Spoofer System Architecture

## 🎯 Purpose

This document describes the high-level architecture of the Raspberry Pi Zero W ECM spoofing system designed to emulate a 2013 Chevrolet Camaro SS 6.2L ECM over the OBD2 port using CAN communication.

---

## 📊 System Overview

```
+---------------------+        +-------------------+        +----------------------+
|   OBD2 Scanner      | <----> |   ECM Spoofer     | <----> |   CAN-Bus Network    |
|  (e.g., Torque app) |        |  (Raspberry Pi)   |        | (PiCAN2 + OBD2 Port) |
+---------------------+        +-------------------+        +----------------------+
```

---

## 🧩 Components

### 1. **Raspberry Pi Zero W**
- Hosts the spoofing software
- Connects via GPIO SPI to PiCAN2 board
- Powers via OBD2 or USB

### 2. **PiCAN2 CAN-Bus Board**
- Adds CAN interface to Raspberry Pi over SPI
- Communicates with OBD2 tools via DB9 connector

### 3. **OBD2 Scanner**
- External device (mobile app, handheld scanner)
- Sends standard OBD2 PID requests

---

## 🧠 Software Architecture

### Core Services:

#### `can0` Interface (SocketCAN)
- Uses `mcp2515` driver via overlays
- Communicates on ISO 15765-4 (11-bit CAN ID, 500kbps)

#### ECM Emulator Daemon (`ecm_emulator.py`)
- Listens on CAN ID `0x7DF` (OBD2 broadcast requests)
- Responds on CAN ID `0x7E8` (ECM typical response ID)

##### Supported Modes:
- **Mode $01:** Current data
  - PID $01 (Monitor readiness) – always "complete"
  - PID $05, $0C, $0D – static/fake sensor data
- **Mode $03:** Show DTCs – always returns empty
- **Mode $04:** Clear DTCs – returns success but does nothing

### Optional:
- Logging system for request/response tracking
- Systemd service for automatic boot-time launch

---

## 🧱 Data Flow

1. OBD2 scanner sends a PID request on `0x7DF`
2. `ecm_emulator.py` receives the message via SocketCAN
3. Parses Mode and PID
4. Constructs spoofed response
5. Sends reply on `0x7E8`
6. Scanner receives valid response with clean data

---

## ⚙️ Boot Process

1. Pi boots → systemd enables CAN overlay
2. Brings up `can0` via init script or systemd
3. Launches ECM emulator daemon
4. Listens for and handles OBD2 traffic

---

## 📡 Communication Protocol

- **CAN ID (OBD2):**
  - Request: `0x7DF`
  - Response: `0x7E8` (ECM)
- **Bitrate:** 500kbps
- **Frame Type:** Standard 11-bit CAN

---

## 🔐 Security and Scope

- No network exposure (no Wi-Fi or BLE required post-setup)
- Passive spoofing only – does not send unsolicited CAN frames
- For closed-loop systems or test harnesses only

---

Let me know if you'd like a diagram or flowchart added visually to this!
