"""Deploy project files to Raspberry Pi"""

import os
import subprocess

def deploy_project():
    # Ensure you're in the project directory
    os.chdir("ecm-spoofer")
    
    # Create deploy directory if it doesn't exist
    if not os.path.exists("deploy"):
        os.makedirs("deploy")
    
    # Copy all necessary files to deploy/
    subprocess.run([
        "cp", "-r", 
        "src/*", 
        "config/*", 
        "scripts/*", 
        "README.md", 
        "deploy/"
    ], check=True)
    
    # Create a tarball for easy transfer
    subprocess.run([
        "tar", "-czvf", 
        "deploy/ecm-spoofer.tar.gz", 
        "deploy/*"
    ], check=True)
    
    print("Project files have been packaged in deploy/ecm-spoofer.tar.gz")

def install_on_raspberry_pi():
    # Deploy and install on Raspberry Pi
    subprocess.run([
        "ssh", 
        "pi@raspberrypi.local", 
        "mkdir -p ~/ecm-spoofer"
    ], check=True)
    
    subprocess.run([
        "scp", 
        "deploy/ecm-spoofer.tar.gz", 
        "pi@raspberrypi.local:~/ecm-spoofer/"
    ], check=True)
    
    subprocess.run([
        "ssh", 
        "pi@raspberrypi.local", 
        "cd ~/ecm-spoofer && tar -xzvf ecm-spoofer.tar.gz && chmod +x scripts/*"
    ], check=True)

if __name__ == '__main__':
    try:
        deploy_project()
        install_on_raspberry_pi()
        print("Deployment completed successfully!")
    except subprocess.CalledProcessError as e:
        print(f"Error occurred: {str(e)}")
        sys.exit(1)

# Make the script executable
subprocess.run(["chmod", "755", "deploy.py"], check=True)