"""Install dependencies and setup the environment"""

import subprocess
import sys
import os

def install_dependencies():
    # Update system packages
    subprocess.run(["sudo", "apt", "update", "-y"], check=True)
    subprocess.run(["sudo", "apt", "upgrade", "-y"], check=True)
    
    # Install required tools
    subprocess.run(["sudo", "apt", "install", "-y", 
                   "git", 
                   "python3", 
                   "python3-dev", 
                   "python3-pip", 
                   "libpython3-dev", 
                   "socketcan", 
                   "can-utils"], 
                  check=True)
    
    # Install Python packages
    subprocess.run(["pip3", "install", 
                   "python-can", 
                   "pyserial"], 
                  check=True)

def configure_can_interface():
    # Create can0 interface config file
    with open('config/can_interface.conf', 'w') as f:
        f.write('[CAN0]\n')
        f.write('BITRATE=500000\n')
        f.write('SAMPLE=1\n')
    
    # Reload CAN configuration
    subprocess.run(["sudo", "modprobe", "can_raw"], check=True)
    subprocess.run(["sudo", "modprobe", "can_socketcan"], check=True)
    subprocess.run(["sudo", "ip", "link", "set", "can0", "type", "can", " bitrate", "500000"], check=True)
    subprocess.run(["sudo", "ifconfig", "can0", "up"], check=True)

if __name__ == '__main__':
    try:
        install_dependencies()
        configure_can_interface()
        print("Setup completed successfully!")
    except subprocess.CalledProcessError as e:
        print(f"Error occurred: {str(e)}")
        sys.exit(1)

# Make the script executable
subprocess.run(["chmod", "755", "setup.py"], check=True)