"""Spoofing ECM responses for 2013 Camaro SS"""

import can
import time
import logging

# Configure logging
logging.basicConfig(
    level=logging.INFO,
    format='%(asctime)s - %(levelname)s - %(message)s'
)

# Configuration
ECU_ID = 0x7E8  # Standard OBD2 ECM ID
TESTER_ID = 0x7DF  # Standard OBD2 tester ID

# Initialize CAN bus
try:
    bus = can.Bus(interface='socketcan', channel='can0', bitrate=500000)
except Exception as e:
    logging.error(f"Failed to initialize CAN bus: {str(e)}")
    sys.exit(1)

# Define response templates
class ResponseTemplate:
    def __init__(self, data):
        self.data = data

    def to_bytes(self):
        return bytes(self.data)

# Default response handler
def handle_request(arbitration_id, data):
    logging.debug(f"Received message on {arbitration_id}: {data.hex()}")
    # Default response for unsupported requests
    return can.Message(arbitration_id=ECU_ID, data=[0x00] * 8)

# Main loop
if __name__ == '__main__':
    try:
        logging.info("Starting ECM spoofer...")
        while True:
            # Listen for requests
            msg = bus.recv()
            if msg is None:
                continue
                
            if msg.arbitration_id == TESTER_ID:
                # Respond to general OBD requests
                response = can.Message(
                    arbitration_id=ECU_ID,
                    data=[0x00] * 8,
                    dlc=8,
                    extended_id=False
                )
                bus.send(response)
                logging.info(f"Sent response to {msg.arbitration_id}")
                
            time.sleep(0.1)
            
    except KeyboardInterrupt:
        logging.info("Stopping ECM spoofer...")
        bus.close()
    except Exception as e:
        logging.error(f"Critical error occurred: {str(e)}")
        bus.close()
        sys.exit(1)